
paneWidth = 800;
paneHeight = 50;
defaultFont = Turbine.UI.Lotro.Font.Verdana12;

-- Inherit from the Control class
TChanPane = class(Turbine.UI.Control);

-- Make a custom constructor to initialize member elements
function TChanPane:Constructor(left, top, width, height)
	Turbine.UI.Control.Constructor( self );
	
	if (width ~= nil) and (height ~= nil) and (left ~= nil) and (top ~= nil) then
		self:SetSize(width, height);
		self:SetPosition(left, top);
	end
	
	-- Create channel info fields and help labels
	self.cnameLabel = TLabel("Channel Name:",0,0,50,24);
	self.cnameLabel:SetFont(defaultFont);
	self.cnameLabel:SetForeColor(Turbine.UI.Color(1,1,1));
	self.cnameEdit = TEdit(60,0,180,24);
	self.cnameEdit:SetFont(defaultFont);
	self.cnameEdit:SetForeColor(Turbine.UI.Color(1,1,1));
	self.cnameEdit:SetMultiline(false);
	self.cpassLabel = TLabel("Pass:",245,0,30,24);
	self.cpassLabel:SetFont(defaultFont);
	self.cpassLabel:SetForeColor(Turbine.UI.Color(1,1,1));
	self.cpassEdit = TEdit(280,0,180,24);
	self.cpassEdit:SetFont(defaultFont);
	self.cpassEdit:SetForeColor(Turbine.UI.Color(1,1,1));
	self.cpassEdit:SetMultiline(false);
	-- Graphics for join and leave buttons
	self.enterGfxContainer = TContainer(510,0,24,24);
	self.enterGfxBtn = TImage(pluginRoot .. "Resources/Enter_icon.tga",0,0,24,24);
	self.leaveGfxContainer = TContainer(550,0,24,24);
	self.leaveGfxBtn = TImage(pluginRoot .. "Resources/Leave_icon.tga",0,0,24,24);
	
	-- Invisible windows and quickslots for chat join and leave buttons.
	self.enterWindow = TCmdContainer(510,0,24,24);
	self.enterBtn = TCommand(0,0,24,24);
	self.leaveWindow = TCmdContainer(550,0,24,24);
	self.leaveBtn = TCommand(0,0,24,24);
	
	self.enterCmd = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias,nil);
	self.leaveCmd = Turbine.UI.Lotro.Shortcut(Turbine.UI.Lotro.ShortcutType.Alias,nil);
	
	-- Tie all of the above to together in this panel
	self.cnameLabel:SetParent(self);
	self.cnameEdit:SetParent(self);
	self.cpassLabel:SetParent(self);
	self.cpassEdit:SetParent(self);
	self.enterGfxContainer:SetParent(self);
	self.enterGfxBtn:SetParent(self.enterGfxContainer);
	self.leaveGfxContainer:SetParent(self);
	self.leaveGfxBtn:SetParent(self.leaveGfxContainer);
	
	self.enterWindow:SetParent(self);
	self.enterBtn:SetZOrder(2);
	self.enterBtn:SetParent(self.enterWindow);
	self.leaveWindow:SetParent(self);
	self.leaveBtn:SetZOrder(2);
	self.leaveBtn:SetParent(self.leaveWindow);
	-- Hide but enable quickslot windows
	self.enterWindow:SetOpacity(0);
	self.enterWindow:SetMouseVisible(true);
	self.enterWindow:SetVisible(true);
	
	self.leaveWindow:SetOpacity(0);
	self.leaveWindow:SetMouseVisible(true);
	self.leaveWindow:SetVisible(true);
	
	self.initButton = TButton("=>",465,0,40,24);
	self.initButton:SetParent(self);
	self.initButton:SetFont(Turbine.UI.Lotro.Font.VerdanaBold16);
	self.initButton:SetText(self.initButton:GetText()); -- HACK to redraw button with the above settings
	
	self.initButton.MouseClick = function( sender, args )
		self:InitCommands();
	end
end


function TChanPane:InitCommands()
	local nameTxt, passTxt;
	
	nameTxt = self.cnameEdit:GetText();
	passTxt = self.cpassEdit:GetText();
	
	if (nameTxt ~= nil) and (nameTxt ~= "") then
		debug("@InitCommands: " .. "Setting channel " .. nameTxt .. " ".. passTxt);
		self.enterCmd:SetData("/joinchannel " .. nameTxt .. " " .. passTxt);
		self.enterBtn:SetShortcut(self.enterCmd);
		self.leaveCmd:SetData("/leavechannel " .. nameTxt);
		self.leaveBtn:SetShortcut(self.leaveCmd);
	else
		debug("@InitCommands");
		self.enterBtn:SetShortcut(nil);
		self.leaveBtn:SetShortcut(nil);
	end
end
---------------------------


